ResourceBuilder
Usage
ResourceBuilder(
name,
template_name,
template_version="1.0",
*,
backend,
namespace_context,
parent=None,
resource_id=None,
on_existing="warn",
command_context,
transaction=None
)Methods
| Name | Description |
|---|---|
| get_model() | Return a pydantic model representing the resource, optionally reloading |
get_model()
Return a pydantic model representing the resource, optionally reloading
Usage
get_model(*, update=False)from the backend first. Critical fields are locked against mutation.